@@ -8,15 +8,16 @@ import abc
 import datetime
 import logging
 import random
+from contextlib import suppress
 from queue import Empty, LifoQueue
 from threading import Lock
 
 import requests.adapters
 import requests.sessions
-from oauthlib.oauth2 import BackendApplicationClient, WebApplicationClient
+from oauthlib.oauth2 import BackendApplicationClient, LegacyApplicationClient, WebApplicationClient
 from requests_oauthlib import OAuth2Session
 
-from .credentials import OAuth2AuthorizationCodeCredentials, OAuth2Credentials
+from .credentials import OAuth2AuthorizationCodeCredentials, OAuth2Credentials, OAuth2LegacyCredentials
 from .errors import (
     CASError,
     ErrorInvalidSchemaVersionForMailboxVersion,
@@ -221,10 +222,8 @@ class BaseProtocol:
             session = self._session_pool.get(block=False)
             log.debug("Server %s: Got session immediately", self.server)
         except Empty:
-            try:
+            with suppress(SessionPoolMaxSizeReached):
                 self.increase_poolsize()
-            except SessionPoolMaxSizeReached:
-                pass
             while True:
                 try:
                     log.debug("Server %s: Waiting for session", self.server)
@@ -314,7 +313,7 @@ class BaseProtocol:
 
     def create_oauth2_session(self):
         session_params = {"token": self.credentials.access_token}  # Token may be None
-        token_params = {}
+        token_params = {"include_client_id": True}
 
         if isinstance(self.credentials, OAuth2AuthorizationCodeCredentials):
             token_params["code"] = self.credentials.authorization_code  # Auth code may be None
@@ -336,10 +335,19 @@ class BaseProtocol:
                     }
                 )
             client = WebApplicationClient(client_id=self.credentials.client_id)
+        elif isinstance(self.credentials, OAuth2LegacyCredentials):
+            client = LegacyApplicationClient(client_id=self.credentials.client_id)
+            token_params["username"] = self.credentials.username
+            token_params["password"] = self.credentials.password
         else:
             client = BackendApplicationClient(client_id=self.credentials.client_id)
 
-        session = self.raw_session(self.service_endpoint, oauth2_client=client, oauth2_session_params=session_params)
+        session = self.raw_session(
+            self.service_endpoint,
+            oauth2_client=client,
+            oauth2_session_params=session_params,
+            oauth2_token_endpoint=self.credentials.token_url,
+        )
         if not session.token:
             # Fetch the token explicitly -- it doesn't occur implicitly
             token = session.fetch_token(
@@ -358,7 +366,7 @@ class BaseProtocol:
         return session
 
     @classmethod
-    def raw_session(cls, prefix, oauth2_client=None, oauth2_session_params=None):
+    def raw_session(cls, prefix, oauth2_client=None, oauth2_session_params=None, oauth2_token_endpoint=None):
         if oauth2_client:
             session = OAuth2Session(client=oauth2_client, **(oauth2_session_params or {}))
         else:
@@ -366,6 +374,8 @@ class BaseProtocol:
         session.headers.update(DEFAULT_HEADERS)
         session.headers["User-Agent"] = cls.USERAGENT
         session.mount(prefix, adapter=cls.get_adapter())
+        if oauth2_token_endpoint:
+            session.mount(oauth2_token_endpoint, adapter=cls.get_adapter())
         return session
 
     def __repr__(self):
