@@ -1,5 +1,6 @@
 import abc
 import logging
+from contextlib import suppress
 from itertools import chain
 
 from .. import errors
@@ -67,13 +68,13 @@ from ..version import API_VERSIONS, Version
 
 log = logging.getLogger(__name__)
 
-PAGE_SIZE = 100  # A default page size for all paging services. This is the number of items we request per page
-CHUNK_SIZE = 100  # A default chunk size for all services. This is the number of items we send in a single request
-
 
 class EWSService(metaclass=abc.ABCMeta):
     """Base class for all EWS services."""
 
+    PAGE_SIZE = 100  # A default page size for all paging services. This is the number of items we request per page
+    CHUNK_SIZE = 100  # A default chunk size for all services. This is the number of items we send in a single request
+
     SERVICE_NAME = None  # The name of the SOAP service
     element_container_name = None  # The name of the XML element wrapping the collection of returned items
     paging_container_name = None  # The name of the element that contains paging information and the paged results
@@ -106,7 +107,7 @@ class EWSService(metaclass=abc.ABCMeta):
     supports_paging = False
 
     def __init__(self, protocol, chunk_size=None, timeout=None):
-        self.chunk_size = chunk_size or CHUNK_SIZE
+        self.chunk_size = chunk_size or self.CHUNK_SIZE
         if not isinstance(self.chunk_size, int):
             raise InvalidTypeError("chunk_size", chunk_size, int)
         if self.chunk_size < 1:
@@ -305,7 +306,6 @@ class EWSService(metaclass=abc.ABCMeta):
                 account_to_impersonate=self._account_to_impersonate,
                 timezone=self._timezone,
             ),
-            allow_redirects=False,
             stream=self.streaming,
             timeout=self.timeout or self.protocol.TIMEOUT,
         )
@@ -388,10 +388,8 @@ class EWSService(metaclass=abc.ABCMeta):
         """
         log.debug("Got ErrorServerBusy (back off %s seconds)", e.back_off)
         # ErrorServerBusy is very often a symptom of sending too many requests. Scale back connections if possible.
-        try:
+        with suppress(SessionPoolMinSizeReached):
             self.protocol.decrease_poolsize()
-        except SessionPoolMinSizeReached:
-            pass
         if self.protocol.retry_policy.fail_fast:
             raise e
         self.protocol.retry_policy.back_off(e.back_off)
@@ -477,12 +475,10 @@ class EWSService(metaclass=abc.ABCMeta):
             msg_xml = detail.find(f"{{{TNS}}}MessageXml")  # Crazy. Here, it's in the TNS namespace
             if code == "ErrorServerBusy":
                 back_off = None
-                try:
+                with suppress(TypeError, AttributeError):
                     value = msg_xml.find(f"{{{TNS}}}Value")
                     if value.get("Name") == "BackOffMilliseconds":
                         back_off = int(value.text) / 1000.0  # Convert to seconds
-                except (TypeError, AttributeError):
-                    pass
                 raise ErrorServerBusy(msg, back_off=back_off)
             if code == "ErrorSchemaValidation" and msg_xml is not None:
                 line_number = get_xml_attr(msg_xml, f"{{{TNS}}}LineNumber")
@@ -496,10 +492,8 @@ class EWSService(metaclass=abc.ABCMeta):
                 raise vars(errors)[code](msg)
             except KeyError:
                 detail = f"{cls.SERVICE_NAME}: code: {code} msg: {msg} ({xml_to_str(detail)})"
-        try:
+        with suppress(KeyError):
             raise vars(errors)[fault_code](fault_string)
-        except KeyError:
-            pass
         raise SOAPError(f"SOAP error code: {fault_code} string: {fault_string} actor: {fault_actor} detail: {detail}")
 
     def _get_element_container(self, message, name=None):
@@ -717,7 +711,7 @@ class EWSAccountService(EWSService, metaclass=abc.ABCMeta):
 
 class EWSPagingService(EWSAccountService):
     def __init__(self, *args, **kwargs):
-        self.page_size = kwargs.pop("page_size", None) or PAGE_SIZE
+        self.page_size = kwargs.pop("page_size", None) or self.PAGE_SIZE
         if not isinstance(self.page_size, int):
             raise InvalidTypeError("page_size", self.page_size, int)
         if self.page_size < 1:
